@@ -192,10 +192,10 @@ class GitRepository(object):
         """
         if not cwd:
             cwd = self.path
-        return self.__git_inout(command, args, input, extra_env, cwd, capture_stderr, config_args)
+        return self.git_inout(command, args, input, extra_env, cwd, capture_stderr, config_args)
 
     @classmethod
-    def __git_inout(cls, command, args, input, extra_env, cwd, capture_stderr, config_args=None):
+    def git_inout(cls, command, args, input, extra_env, cwd, capture_stderr, config_args=None):
         """
         As _git_inout but can be used without an instance
         """
@@ -1186,10 +1186,10 @@ class GitRepository(object):
             fetch_url = None
             push_urls = []
             for line in out.decode().splitlines():
-                match = re.match('\s*Fetch\s+URL:\s*(\S.*)', line)
+                match = re.match(r'\s*Fetch\s+URL:\s*(\S.*)', line)
                 if match:
                     fetch_url = match.group(1)
-                match = re.match('\s*Push\s+URL:\s*(\S.*)', line)
+                match = re.match(r'\s*Push\s+URL:\s*(\S.*)', line)
                 if match:
                     push_urls.append(match.group(1))
             remotes[remote] = GitRemote(remote, fetch_url, push_urls)
@@ -1884,7 +1884,6 @@ class GitRepository(object):
         args.add_true(auto, '--auto')
         self._git_command("gc", args.args)
 
-
 #{ Submodules
 
     def has_submodules(self, treeish=None):
@@ -2002,12 +2001,12 @@ class GitRepository(object):
             if not os.path.exists(abspath):
                 os.makedirs(abspath)
             try:
-                stdout, stderr, ret = cls.__git_inout(command='init',
-                                                      args=args.args,
-                                                      input=None,
-                                                      extra_env=None,
-                                                      cwd=abspath,
-                                                      capture_stderr=True)
+                stdout, stderr, ret = cls.git_inout(command='init',
+                                                    args=args.args,
+                                                    input=None,
+                                                    extra_env=None,
+                                                    cwd=abspath,
+                                                    capture_stderr=True)
             except Exception as excobj:
                 raise GitRepositoryError("Error running git init: %s" % excobj)
             if ret:
@@ -2068,12 +2067,12 @@ class GitRepository(object):
                 os.makedirs(abspath)
 
             try:
-                stdout, stderr, ret = cls.__git_inout(command='clone',
-                                                      args=args.args,
-                                                      input=None,
-                                                      extra_env=None,
-                                                      cwd=abspath,
-                                                      capture_stderr=True)
+                stdout, stderr, ret = cls.git_inout(command='clone',
+                                                    args=args.args,
+                                                    input=None,
+                                                    extra_env=None,
+                                                    cwd=abspath,
+                                                    capture_stderr=True)
             except Exception as excobj:
                 raise GitRepositoryError("Error running git clone: %s" % excobj)
             if ret:
